const axios = require('axios');
const Eval = require('./Eval');

module.exports = class AdmEval {
  /**
   * @constructor
   * @param {String} apiUrl
   * @return {AdmEval}
   */
  constructor(apiUrl) {
    this.ApiBaseUrl = apiUrl
    this.Api = null
    this.setApi();
  }

  setApi() {
    this.Api = axios.create({
      baseUrl: this.ApiBaseUrl
    })
  }

  /**
  * @param {String} apiUrl
  * Set new api with axios  
  */
  setNewApi(apiUrl) {
    this.ApiBaseUrl = apiUrl
    this.setApi();
  }

  async createEval(object, head, urlPath) {
    if (Eval.check(object)) {
      try {
        const info = object.getInfo();
        const response = await this.Api.post(this.ApiBaseUrl + urlPath, {
          idEvaluator: info.idEvaluator,
          idRated: info.idRated,
          evaluation: info.eval,
          comment: info.comment,
          object: info.obj,
          type: info.type,
          date: info.date,
        }, {
          headers: head
        })

        return response

      } catch (error) {
        throw new Error(error)
      }
    } else {
      throw new Error('Expecting an (Eval) type object');
    }
  }

  async searchEval(id, idEvaluator, idRated, type, head, urlPath) {
    try {
      const response = await this.Api.get(this.ApiBaseUrl + urlPath, {
        params: {
          id,
          idEvaluator,
          idRated,
          type
        },
        headers: head
      })

      return response.data

    } catch (error) {
      console.log(error);
      throw new Error(error)
    }
  }

  async deleteEval(id, head, urlGetPath, urlPath, idEvaluator, idRated, type) {
    try {
      let resp = await this.searchEval(id, idEvaluator, idRated, type, head, urlGetPath);
      if (resp[0]) {
        console.log(resp[0]);
        try {
          const id = resp[0].id;
          const response = await this.Api.delete(this.ApiBaseUrl + urlPath, {
            params: {
              id
            },
            headers: head
          })
          return response
        } catch (error) {
          throw new Error(error);
        }
      }
    } catch (error) {
      console.log(error);
      throw new Error(error);
    }
  }

  async listEval(urlPath) {
    try {
      const response = await this.Api.get(urlPath)

      return response.data

    } catch (error) {
      console.log(error);
      throw new Error(error)
    }
  }

  async editEval(id, idEvaluator, idRated, evaluation, comment, object, type, headSearch, headEdit, urlSearchPath, urlEditPath) {
    try {
      const response = await this.searchEval(id, idEvaluator, idRated, type, headSearch, urlSearchPath);

      if (response) {
        try {
          const responseEdit = await this.Api.put(this.ApiBaseUrl + urlEditPath, {
            evaluation,
            comment,
            object,
            type
          }, {
            headers: headEdit,
            params: {
              id
            }
          })
          return responseEdit.data;

        } catch (error) {
          throw new Error('From Edit: ' + error);
        }
      }
    } catch (error) {
      throw new Error('From Search: ' + error);
    }
  }
}